@@ -2,7 +2,13 @@
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 """
 
-from .model import ModelBase, make_model, make_model_class, run_function_with_cmd_args
+from .model import (
+    ModelBase,
+    make_model,
+    make_model_class,
+    run_function_with_cmd_args,
+    run_script,
+)
 from .parameters import Parameter
 from .results import Result, ResultCollection
 from .run import submit_job, submit_jobs
