@@ -14,7 +14,7 @@ import logging
 import os.path
 import warnings
 from pathlib import Path
-from typing import Any, Dict, Iterator, List, Set, Tuple, Type, Union
+from typing import Any, Dict, Iterator, List, Optional, Set, Tuple, Type, Union
 
 import numpy as np
 from tqdm.auto import tqdm
@@ -50,23 +50,22 @@ class NumpyEncoder(json.JSONEncoder):
         return json.JSONEncoder.default(self, obj)
 
 
-def prepare_yaml(data):
-    """prepare data for writing to yaml"""
+def simplify_data(data):
+    """simplify data (e.g. for writing to yaml)"""
     if isinstance(data, dict):
-        data = data.copy()  # shallow copy of result
-        for key, value in data.items():
-            if isinstance(value, dict):
-                data[key] = prepare_yaml(value)
-            elif isinstance(value, tuple):
-                data[key] = list(value)
-            elif isinstance(value, list) and value and not np.isscalar(value[0]):
-                data[key] = [prepare_yaml(a) for a in value]
-            elif isinstance(value, np.ndarray) and value.size <= 100:
-                # for less than ~100 items a list is actually more efficient to store
-                data[key] = value.tolist()
+        data = {key: simplify_data(value) for key, value in data.items()}
 
-    elif isinstance(data, np.ndarray) and data.size <= 100:
-        # for less than ~100 items a list is actually more efficient to store
+    elif isinstance(data, (tuple, list)):
+        data = [simplify_data(item) for item in data]
+
+    elif isinstance(data, np.ndarray):
+        if np.isscalar(data):
+            data = data.item()
+        elif data.size <= 100:
+            # for less than ~100 items a list is actually more efficient to store
+            data = data.tolist()
+
+    elif isinstance(data, np.number):
         data = data.tolist()
 
     return data
@@ -124,7 +123,7 @@ def read_hdf_data(node):
 class MockModel(ModelBase):
     """helper class to store parameter values when the original model is not present"""
 
-    def __init__(self, parameters: Dict[str, Any] = None):
+    def __init__(self, parameters: Optional[Dict[str, Any]] = None):
         """
         Args:
             parameters (dict): A dictionary of parameters
@@ -141,7 +140,7 @@ class MockModel(ModelBase):
 class Result:
     """describes a model (with parameters) together with its result"""
 
-    def __init__(self, model: ModelBase, result, info: Dict[str, Any] = None):
+    def __init__(self, model: ModelBase, result, info: Optional[Dict[str, Any]] = None):
         """
         Args:
             model (:class:`ModelBase`): The model from which the result was obtained
@@ -160,8 +159,8 @@ class Result:
         cls,
         model_data: Dict[str, Any],
         result,
-        model: ModelBase = None,
-        info: Dict[str, Any] = None,
+        model: Optional[ModelBase] = None,
+        info: Optional[Dict[str, Any]] = None,
     ) -> Result:
         """create result from data
 
@@ -189,7 +188,7 @@ class Result:
         return self.model.parameters
 
     @classmethod
-    def from_file(cls, path, model: ModelBase = None):
+    def from_file(cls, path, model: Optional[ModelBase] = None):
         """read result from file
 
         Args:
@@ -223,7 +222,7 @@ class Result:
             raise ValueError(f"Unknown file format `{ext}`")
 
     @classmethod
-    def from_json(cls, path, model: ModelBase = None) -> Result:
+    def from_json(cls, path, model: Optional[ModelBase] = None) -> Result:
         """read result from a JSON file
 
         Args:
@@ -249,7 +248,10 @@ class Result:
         Args:
             path (str or :class:`~pathlib.Path`): The path to the file
         """
-        data = {"model": self.model.attributes, "result": self.result}
+        data = {
+            "model": simplify_data(self.model.attributes),
+            "result": simplify_data(self.result),
+        }
         if self.info:
             data["info"] = self.info
 
@@ -257,7 +259,7 @@ class Result:
             json.dump(data, fp, cls=NumpyEncoder)
 
     @classmethod
-    def from_yaml(cls, path, model: ModelBase = None) -> Result:
+    def from_yaml(cls, path, model: Optional[ModelBase] = None) -> Result:
         """read result from a YAML file
 
         Args:
@@ -288,7 +290,10 @@ class Result:
         import yaml
 
         # compile all data
-        data = {"model": self.model.attributes, "result": prepare_yaml(self.result)}
+        data = {
+            "model": simplify_data(self.model.attributes),
+            "result": simplify_data(self.result),
+        }
         if self.info:
             data["info"] = self.info
 
@@ -296,7 +301,7 @@ class Result:
             yaml.dump(data, fp)
 
     @classmethod
-    def from_hdf(cls, path, model: ModelBase = None) -> Result:
+    def from_hdf(cls, path, model: Optional[ModelBase] = None) -> Result:
         """read result from a HDf file
 
         Args:
@@ -331,10 +336,12 @@ class Result:
         with h5py.File(path, "w") as fp:
             # write attributes
             for key, value in self.model.attributes.items():
-                fp.attrs[key] = json.dumps(value, cls=NumpyEncoder)
+                fp.attrs[key] = json.dumps(simplify_data(value), cls=NumpyEncoder)
 
             if self.info:
-                fp.attrs["__info__"] = json.dumps(self.info, cls=NumpyEncoder)
+                fp.attrs["__info__"] = json.dumps(
+                    simplify_data(self.info), cls=NumpyEncoder
+                )
 
             # write the actual data
             write_hdf_dataset(fp, self.result, "result")
@@ -348,7 +355,7 @@ class ResultCollection(List[Result]):
         cls,
         folder: Union[str, Path],
         pattern: str = "*.*",
-        model: ModelBase = None,
+        model: Optional[ModelBase] = None,
         *,
         strict: bool = False,
         progress: bool = False,
